# renameit
> Pure python CLI tool for renaming files and folders locally or on the cloud.

# Description

Reshape your data lakes by transforming files and folders structure with a single command and without the complications of writing manual scripts.
Data engineers and data analysts constantly have to worry about keeping the structure of their data organized in order to efficiently read
and access them. This tool allows them to change the file or folder structure of their data lakes on a cloud storage system or even on local storage
(e.g. locally mounted cloud storage).

---

[![Open in Remote - Containers](https://img.shields.io/static/v1?label=Remote%20-%20Containers&message=Open&color=blue&logo=visualstudiocode)](https://vscode.dev/redirect?url=vscode://ms-vscode-remote.remote-containers/cloneInVolume?url=https://github.com/Hasan-J/renameit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Main](https://github.com/Hasan-J/renameit/actions/workflows/main.yml/badge.svg)](https://github.com/Hasan-J/renameit/actions/workflows/main.yml)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/renameit)
![PyPI](https://img.shields.io/pypi/v/renameit)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)

# Documentaion

Full documentation available [here](https://hasan-j.github.io/renameit/).

# License

Distributed under the MIT License. See ``LICENSE`` for more information.
